# RADICAL-Utils (RU)

[![Build Status](https://github.com/radical-cybertools/radical.utils/actions/workflows/ci.yml/badge.svg)](https://github.com/radical-cybertools/radical.utils/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/radical-cybertools/radical.utils/branch/devel/graph/badge.svg)](https://codecov.io/gh/radical-cybertools/radical.utils)

RADICAL-Utils (RU) is a Python package, which contains shared code and tools for
various [RADICAL-Cybertools](https://radical-cybertools.github.io).

## Documentation

Package description and usage examples are available at:
https://radicalutils.readthedocs.io/en/stable/ (**under development**)

## Code

Generally, the `master` branch reflects the RU release published on
[PyPI](https://pypi.org/project/radical.utils/).

The `devel` branch (and any branch other than master) may not correspond to the 
published documentation and, specifically, may have dependencies which need to 
be resolved manually.

## License

This software is released under the
[MIT License](http://opensource.org/licenses/MIT).

Parts of the module (`radical.utils.atfork`) are licensed under the 
[Apache-v2.0 license](http://www.apache.org/licenses/).
